==> tag_1.0.0.zip: server/src/main/java/cn/com/qmth/scancloud/controller/admin/ExamWorkController.java <==
package cn.com.qmth.scancloud.controller.admin;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;

import cn.com.qmth.scancloud.entity.SubjectEntity;
import cn.com.qmth.scancloud.service.StudentService;
import cn.com.qmth.scancloud.service.SubjectService;
import cn.com.qmth.scancloud.vo.student.StudentQuery;
import cn.com.qmth.scancloud.vo.student.StudentVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@Api(tags = "考务接口")
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/admin")
@Aac(strict = BOOL.FALSE, auth = BOOL.TRUE)
public class ExamWorkController {

    @Autowired
    private StudentService studentService;

    @Autowired
    private SubjectService subjectService;

    @ApiOperation(value = "获取考生信息")
    @RequestMapping(value = "/student/find", method = RequestMethod.POST)
    public StudentVo student(StudentQuery query) {
        return studentService.findOne(query);
    }

    @ApiOperation(value = "获取科目列表")
    @RequestMapping(value = "/subject/list", method = RequestMethod.POST)
    public List<SubjectEntity> subjectList(@RequestParam Long examId) {
        return subjectService.listByExamId(examId);
    }

    @ApiOperation(value = "获取科目信息")
    @RequestMapping(value = "/subject/find", method = RequestMethod.POST)
    public SubjectEntity subjectFind(@RequestParam Long examId, @RequestParam String code) {
        return subjectService.findByExamIdAndCode(examId, code);
    }

    @ApiOperation(value = "获取所有学习中心")
    @RequestMapping(value = "/campus/list", method = RequestMethod.POST)
    public List<String> campusList(@RequestParam Long examId) {
        return studentService.listCampusByExamId(examId);
    }

    @ApiOperation(value = "获取所有考点")
    @RequestMapping(value = "/exam_site/list", method = RequestMethod.POST)
    public List<String> siteList(@RequestParam Long examId) {
        return studentService.listSiteByExamId(examId);
    }
}

==> tag_1.0.2.zip: server/src/main/java/cn/com/qmth/scancloud/controller/admin/ExamWorkController.java <==
package cn.com.qmth.scancloud.controller.admin;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;

import cn.com.qmth.scancloud.entity.SubjectEntity;
import cn.com.qmth.scancloud.service.StudentService;
import cn.com.qmth.scancloud.service.SubjectService;
import cn.com.qmth.scancloud.vo.CampusVo;
import cn.com.qmth.scancloud.vo.ExamSiteVo;
import cn.com.qmth.scancloud.vo.student.StudentQuery;
import cn.com.qmth.scancloud.vo.student.StudentVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@Api(tags = "考务接口")
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/admin")
@Aac(strict = BOOL.FALSE, auth = BOOL.TRUE)
public class ExamWorkController {

    @Autowired
    private StudentService studentService;

    @Autowired
    private SubjectService subjectService;

    @ApiOperation(value = "获取考生信息")
    @RequestMapping(value = "/student/find", method = RequestMethod.POST)
    public StudentVo student(@Validated StudentQuery query) {
        return studentService.findOne(query);
    }

    @ApiOperation(value = "获取科目列表")
    @RequestMapping(value = "/subject/list", method = RequestMethod.POST)
    public List<SubjectEntity> subjectList(@RequestParam Long examId) {
        return subjectService.listByExamId(examId);
    }

    @ApiOperation(value = "获取科目信息")
    @RequestMapping(value = "/subject/find", method = RequestMethod.POST)
    public SubjectEntity subjectFind(@RequestParam Long examId, @RequestParam String code) {
        return subjectService.findByExamIdAndCode(examId, code);
    }

    @ApiOperation(value = "获取所有学习中心")
    @RequestMapping(value = "/campus/list", method = RequestMethod.POST)
    public List<CampusVo> campusList(@RequestParam Long examId) {
        return studentService.listCampusByExamId(examId);
    }

    @ApiOperation(value = "获取所有考点")
    @RequestMapping(value = "/exam_site/list", method = RequestMethod.POST)
    public List<ExamSiteVo> siteList(@RequestParam Long examId) {
        return studentService.listSiteByExamId(examId);
    }
}
